@@ -67,7 +67,7 @@ class DiscreteEnv(gym.Env):
     self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
-    self.horizon=20
+    #self.horizon=20
     
     
 
@@ -82,13 +82,13 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
+    self.state = self.df   #self.df.sample(n=1, random_state=1).values.reshape(3,) 
     
     data = []
-    for self.state in self.df.itertuples(index=False):
-      Xs = self.state[0]
-      Xa = self.state[1]
-      Y = self.state[2]
+    for row in self.df    #.itertuples(index=False):
+      Xs = row[0]
+      Xa = row[1]
+      Y = row[2]
       Xsa=(self.thetas[0])+(self.thetas[1])*(Xs)+(self.thetas[2])*(Xa)
       rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
       g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
@@ -106,33 +106,22 @@ class DiscreteEnv(gym.Env):
     thetas1 = np.array([model1.coef_[0,0] , model1.coef_[0,1], model1.intercept_[0]])
     #extract theta parameter for Xa from the fitted logistic
     theta_updated = np.array([model1.coef_[0,1]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
+    
+    Z1 = ((thetas1[0])+(thetas1[1])*(df_new["Xs"])+(thetas1[2])*(df_new["Xa"]))
+    Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
 
-
-    list1= []
-    for i in df_new.itertuples(index=False):
-      Xss = i[0] #no change
-      Xaa = i[1] #no change
-      YY = i[2] #no change
-
-      Z1 = ((thetas1[0])+(thetas1[1])*(Xss)+(thetas1[2])*(Xaa))
-      Prob1 = np.exp(Z1)/(1+np.exp(Z1)) #P(Y=1)
-  
-
-      list1.append([Prob1])
-
-    list_new = pd.DataFrame(list1, columns=['Prob1']) 
-    self.Ynew_cumul = np.mean(list_new["Prob1"])
+    self.Ynew_cumul = np.mean(Prob1)
     #reduce the horizon
-    self.horizon -= 1
+    #self.horizon -= 1
     
     #depending on the value of self.state, apply a reward
     reward = self.Ynew_cumul 
     
     #check if horion is over, otherwise keep on doing
-    if self.horizon <= 0:
-        done = True
-    else:
-        done = False
+    #if self.horizon <= 0:
+     #   done = True
+    #else:
+     #   done = False
 
     #set placeholder for infos
     info ={}        
@@ -141,8 +130,8 @@ class DiscreteEnv(gym.Env):
 
 #reset state and horizon    
   def reset(self):
-    self.state= self.df.sample(n=1, random_state=1).values.reshape(3,) 
-    self.horizon = 20
+    self.state= self.df    #.sample(n=1, random_state=1).values.reshape(3,) 
+    #self.horizon = 20
     return self.state
 
 
